@@ -5,6 +5,11 @@ try:
 except ImportError as e:
     error = e.msg
 
+    def mount(*args, **kwargs):
+        print(error)
+except OSError as e:
+    error = e.strerror
+
     def mount(*args, **kwargs):
         print(error)
 
